@@ -6,7 +6,7 @@
 * Copyright (c) 2001-2004 Ethan Galstad (nagios@nagios.org)
 * Copyright (c) 2001-2006 Nagios Plugin Development Team
 *
-* Last Modified: $Date: 2007/01/28 21:46:41 $
+* Last Modified: $Date: 2007/05/27 13:46:32 $
 *
 * Description:
 *
@@ -31,12 +31,12 @@
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
-* $Id: check_dhcp.c,v 1.8 2007/01/28 21:46:41 hweiss Exp $
+* $Id: check_dhcp.c,v 1.12 2007/05/27 13:46:32 seanius Exp $
 *
 *****************************************************************************/
 
 const char *progname = "check_dhcp";
-const char *revision = "$Revision: 1.8 $";
+const char *revision = "$Revision: 1.12 $";
 const char *copyright = "2001-2006";
 const char *email = "nagiosplug-devel@lists.sourceforge.net";
 
@@ -182,8 +182,10 @@ typedef struct requested_server_struct{
 #define DHCP_OPTION_BROADCAST_ADDRESS   28
 #define DHCP_OPTION_REQUESTED_ADDRESS   50
 #define DHCP_OPTION_LEASE_TIME          51
+#define DHCP_OPTION_SERVER_IDENTIFIER   54
 #define DHCP_OPTION_RENEWAL_TIME        58
 #define DHCP_OPTION_REBINDING_TIME      59
+#define DHCP_OPTION_END                 255
 
 #define DHCP_INFINITE_TIME              0xFFFFFFFF
 
@@ -248,10 +250,13 @@ int main(int argc, char **argv){
 	int dhcp_socket;
 	int result = STATE_UNKNOWN;
 
+	/* this plugin almost certainly needs root permissions. */
+	np_warn_if_not_root();
+	
 	setlocale (LC_ALL, "");
 	bindtextdomain (PACKAGE, LOCALEDIR);
 	textdomain (PACKAGE);
-	
+
 	if(process_arguments(argc,argv)!=OK){
 		usage4 (_("Could not parse arguments"));
 		}
@@ -400,6 +405,7 @@ int get_hardware_address(int sock,char *interface_name){
 int send_dhcp_discover(int sock){
 	dhcp_packet discover_packet;
 	struct sockaddr_in sockaddr_broadcast;
+    unsigned short opts;
 
 
 	/* clear the packet data structure */
@@ -441,17 +447,20 @@ int send_dhcp_discover(int sock){
 	discover_packet.options[2]='\x53';
 	discover_packet.options[3]='\x63';
 
+    opts = 4;
 	/* DHCP message type is embedded in options field */
-	discover_packet.options[4]=DHCP_OPTION_MESSAGE_TYPE;    /* DHCP message type option identifier */
-	discover_packet.options[5]='\x01';               /* DHCP message option length in bytes */
-	discover_packet.options[6]=DHCPDISCOVER;
+	discover_packet.options[opts++]=DHCP_OPTION_MESSAGE_TYPE;    /* DHCP message type option identifier */
+	discover_packet.options[opts++]='\x01';               /* DHCP message option length in bytes */
+	discover_packet.options[opts++]=DHCPDISCOVER;
 
 	/* the IP address we're requesting */
 	if(request_specific_address==TRUE){
-		discover_packet.options[7]=DHCP_OPTION_REQUESTED_ADDRESS;
-		discover_packet.options[8]='\x04';
-		memcpy(&discover_packet.options[9],&requested_address,sizeof(requested_address));
+		discover_packet.options[opts++]=DHCP_OPTION_REQUESTED_ADDRESS;
+		discover_packet.options[opts++]='\x04';
+		memcpy(&discover_packet.options[opts],&requested_address,sizeof(requested_address));
+		opts += sizeof(requested_address);
 	        }
+	discover_packet.options[opts++]=DHCP_OPTION_END;
 	
 	/* send the DHCPDISCOVER packet to broadcast address */
         sockaddr_broadcast.sin_family=AF_INET;
@@ -487,7 +496,6 @@ int get_dhcp_offer(int sock){
 	struct sockaddr_in source;
 	struct sockaddr_in via;
 	int result=OK;
-	int timeout=1;
 	int responses=0;
 	int x;
 	time_t start_time;
@@ -594,7 +602,6 @@ int get_dhcp_offer(int sock){
 
 /* sends a DHCP packet */
 int send_dhcp_packet(void *buffer, int buffer_size, int sock, struct sockaddr_in *dest){
-	struct sockaddr_in myname;
 	int result;
 
 	result=sendto(sock,(char *)buffer,buffer_size,0,(struct sockaddr *)dest,sizeof(*dest));
@@ -765,9 +772,9 @@ int add_requested_server(struct in_addr server_address){
 int add_dhcp_offer(struct in_addr source,dhcp_packet *offer_packet){
 	dhcp_offer *new_offer;
 	int x;
-	int y;
 	unsigned option_type;
 	unsigned option_length;
+	struct in_addr serv_ident = {0};
 
 	if(offer_packet==NULL)
 		return ERROR;
@@ -789,23 +796,28 @@ int add_dhcp_offer(struct in_addr source,dhcp_packet *offer_packet){
 			printf("Option: %d (0x%02X)\n",option_type,option_length);
 
 		/* get option data */
-		if(option_type==DHCP_OPTION_LEASE_TIME){
+		switch(option_type){
+		case DHCP_OPTION_LEASE_TIME:
 			memcpy(&dhcp_lease_time, &offer_packet->options[x],sizeof(dhcp_lease_time));
 			dhcp_lease_time = ntohl(dhcp_lease_time);
-			}
-		if(option_type==DHCP_OPTION_RENEWAL_TIME){
+			break;
+		case DHCP_OPTION_RENEWAL_TIME:
 			memcpy(&dhcp_renewal_time, &offer_packet->options[x],sizeof(dhcp_renewal_time));
 			dhcp_renewal_time = ntohl(dhcp_renewal_time);
-			}
-		if(option_type==DHCP_OPTION_REBINDING_TIME){
+			break;
+		case DHCP_OPTION_REBINDING_TIME:
 			memcpy(&dhcp_rebinding_time, &offer_packet->options[x],sizeof(dhcp_rebinding_time));
 			dhcp_rebinding_time = ntohl(dhcp_rebinding_time);
+			break;
+		case DHCP_OPTION_SERVER_IDENTIFIER:
+			memcpy(&serv_ident.s_addr, &offer_packet->options[x],sizeof(serv_ident.s_addr));
+			break;
 			}
 
 		/* skip option data we're ignoring */
-		else
-			for(y=0;y<option_length;y++,x++);
-	        }
+		if(option_type!=DHCP_OPTION_REBINDING_TIME)
+			x+=option_length;
+		}
 
 	if(verbose){
 		if(dhcp_lease_time==DHCP_INFINITE_TIME)
@@ -826,7 +838,19 @@ int add_dhcp_offer(struct in_addr source,dhcp_packet *offer_packet){
 	if(new_offer==NULL)
 		return ERROR;
 
-	new_offer->server_address=source;
+	/*
+	 * RFC 2131 (2.) says: "DHCP clarifies the interpretation of the
+	 * 'siaddr' field as the address of the server to use in the next step
+	 * of the client's bootstrap process.  A DHCP server may return its own
+	 * address in the 'siaddr' field, if the server is prepared to supply
+	 * the next bootstrap service (e.g., delivery of an operating system
+	 * executable image).  A DHCP server always returns its own address in
+	 * the 'server identifier' option."  'serv_ident' is the 'server
+	 * identifier' option, 'source' is the 'siaddr' field or (if 'siaddr'
+	 * wasn't available) the IP address we received the DHCPOFFER from.  If
+	 * 'serv_ident' isn't available for some reason, we use 'source'.
+	 */
+	new_offer->server_address=serv_ident.s_addr?serv_ident:source;
 	new_offer->offered_address=offer_packet->yiaddr;
 	new_offer->lease_time=dhcp_lease_time;
 	new_offer->renewal_time=dhcp_renewal_time;
