@@ -7,7 +7,7 @@
 *
 * Original Author : Andreas Ericsson <ae@op5.se>
 *
-* Last Modified: $Date: 2007/03/27 06:53:57 $
+* Last Modified: $Date: 2007/05/27 13:46:32 $
 *
 * Description:
 *
@@ -38,14 +38,14 @@
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
-* $Id: check_icmp.c,v 1.12 2007/03/27 06:53:57 dermoth Exp $
+* $Id: check_icmp.c,v 1.13 2007/05/27 13:46:32 seanius Exp $
 * 
 *****************************************************************************/
 
 /* progname may change */
 /* char *progname = "check_icmp"; */
 char *progname;
-const char *revision = "$Revision: 1.12 $";
+const char *revision = "$Revision: 1.13 $";
 const char *copyright = "2005-2007";
 const char *email = "nagiosplug-devel@lists.sourceforge.net";
 
@@ -372,6 +372,9 @@ main(int argc, char **argv)
 	int result;
 	struct rta_host *host;
 	
+	/* print a helpful error message if geteuid != 0 */
+	np_warn_if_not_root();
+
 	/* we only need to be setsuid when we get the sockets, so do
 	 * that before pointer magic (esp. on network data) */
 	icmp_sockerrno = udp_sockerrno = tcp_sockerrno = sockets = 0;
