@@ -3,15 +3,15 @@
 * Nagios check_snmp plugin
 *
 * License: GPL
-* Copyright (c) 1999-2006 nagios-plugins team
+* Copyright (c) 1999-2007 nagios-plugins team
 *
-* Last Modified: $Date: 2007/02/02 09:10:22 $
+* Last Modified: $Date: 2007/05/29 05:22:32 $
 *
 * Description:
 *
 * This file contains the check_snmp plugin
 *
-*  Check status of remote machines and obtain sustem information via SNMP
+*  Check status of remote machines and obtain system information via SNMP
 *
 *
 * License Information:
@@ -30,13 +30,13 @@
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
-* $Id: check_snmp.c,v 1.69 2007/02/02 09:10:22 dermoth Exp $
+* $Id: check_snmp.c,v 1.72 2007/05/29 05:22:32 dermoth Exp $
 * 
 ******************************************************************************/
 
 const char *progname = "check_snmp";
-const char *revision = "$Revision: 1.69 $";
-const char *copyright = "1999-2006";
+const char *revision = "$Revision: 1.72 $";
+const char *copyright = "1999-2007";
 const char *email = "nagiosplug-devel@lists.sourceforge.net";
 
 #include "common.h"
@@ -84,8 +84,8 @@ int process_arguments (int, char **);
 int validate_arguments (void);
 char *clarify_message (char *);
 int check_num (int);
-int lu_getll (unsigned long *, char *);
-int lu_getul (unsigned long *, char *);
+int llu_getll (unsigned long long *, char *);
+int llu_getul (unsigned long long *, char *);
 char *thisarg (char *str);
 char *nextarg (char *str);
 void print_usage (void);
@@ -124,15 +124,15 @@ size_t nunits = 0;
 size_t unitv_size = 8;
 int verbose = FALSE;
 int usesnmpgetnext = FALSE;
-unsigned long lower_warn_lim[MAX_OIDS];
-unsigned long upper_warn_lim[MAX_OIDS];
-unsigned long lower_crit_lim[MAX_OIDS];
-unsigned long upper_crit_lim[MAX_OIDS];
-unsigned long response_value[MAX_OIDS];
+unsigned long long lower_warn_lim[MAX_OIDS];
+unsigned long long upper_warn_lim[MAX_OIDS];
+unsigned long long lower_crit_lim[MAX_OIDS];
+unsigned long long upper_crit_lim[MAX_OIDS];
+unsigned long long response_value[MAX_OIDS];
 int check_warning_value = FALSE;
 int check_critical_value = FALSE;
 int retries = 0;
-unsigned long eval_method[MAX_OIDS];
+unsigned long long eval_method[MAX_OIDS];
 char *delimiter;
 char *output_delim;
 char *miblist = NULL;
@@ -184,13 +184,13 @@ main (int argc, char **argv)
 	/* create the command line to execute */
 		if(usesnmpgetnext == TRUE) {
 		asprintf(&command_line, "%s -t %d -r %d -m %s -v %s %s %s:%s %s",
-				    PATH_TO_SNMPGETNEXT, timeout_interval, retries, miblist, proto,
-						authpriv, server_address, port, oid);
+			PATH_TO_SNMPGETNEXT, timeout_interval, retries, miblist, proto,
+			authpriv, server_address, port, oid);
 	}else{
 
 		asprintf (&command_line, "%s -t %d -r %d -m %s -v %s %s %s:%s %s",
-	          PATH_TO_SNMPGET, timeout_interval, retries, miblist, proto,
-	          authpriv, server_address, port, oid);
+			PATH_TO_SNMPGET, timeout_interval, retries, miblist, proto,
+			authpriv, server_address, port, oid);
 	}
 	
 	if (verbose)
@@ -204,10 +204,12 @@ main (int argc, char **argv)
 		exit (STATE_UNKNOWN);
 	}
 
+#if 0		/* Removed May 29, 2007 */
 	child_stderr = fdopen (child_stderr_array[fileno (child_process)], "r");
 	if (child_stderr == NULL) {
 		printf (_("Could not open stderr for %s\n"), command_line);
 	}
+#endif
 
 	while (fgets (input_buffer, MAX_INPUT_BUFFER - 1, child_process))
 		asprintf (&output, "%s%s", output, input_buffer);
@@ -268,6 +270,10 @@ main (int argc, char **argv)
 			show = strstr (response, "Counter32: ") + 11;
 			strcpy(type, "c");
 		}
+		else if (strstr (response, "Counter64: ")) {
+			show = strstr (response, "Counter64: ") + 11;
+			strcpy(type, "c");
+		}
 		else if (strstr (response, "INTEGER: "))
 			show = strstr (response, "INTEGER: ") + 9;
 		else if (strstr (response, "STRING: "))
@@ -296,7 +302,7 @@ main (int argc, char **argv)
 				die (STATE_UNKNOWN,_("No valid data returned"));
 			response_value[i] = strtoul (p2, NULL, 10);
 			iresult = check_num (i);
-			asprintf (&show, "%lu", response_value[i]);
+			asprintf (&show, "%llu", response_value[i]);
 		}
 
 		/* Process this block for string matching */
@@ -339,11 +345,11 @@ main (int argc, char **argv)
 		/* Prepend a label for this OID if there is one */
 		if (nlabels > (size_t)1 && (size_t)i < nlabels && labels[i] != NULL)
 			asprintf (&outbuff, "%s%s%s %s%s%s", outbuff,
-			          (i == 0) ? " " : output_delim,
-			          labels[i], mark (iresult), show, mark (iresult));
+				(i == 0) ? " " : output_delim,
+				labels[i], mark (iresult), show, mark (iresult));
 		else
 			asprintf (&outbuff, "%s%s%s%s%s", outbuff, (i == 0) ? " " : output_delim,
-			          mark (iresult), show, mark (iresult));
+				mark (iresult), show, mark (iresult));
 
 		/* Append a unit string for this OID if there is one */
 		if (nunits > (size_t)0 && (size_t)i < nunits && unitv[i] != NULL)
@@ -361,20 +367,25 @@ main (int argc, char **argv)
 
 	if (found == 0)
 		die (STATE_UNKNOWN,
-		     _("%s problem - No data received from host\nCMD: %s\n"),
-		     label,
-		     command_line);
+			_("%s problem - No data received from host\nCMD: %s\n"),
+			label,
+			command_line);
 
+#if 0		/* Removed May 29, 2007 */
 	/* WARNING if output found on stderr */
 	if (fgets (input_buffer, MAX_INPUT_BUFFER - 1, child_stderr))
 		result = max_state (result, STATE_WARNING);
 
 	/* close stderr */
 	(void) fclose (child_stderr);
+#endif
 
 	/* close the pipe */
-	if (spclose (child_process))
-		result = max_state (result, STATE_WARNING);
+	if (spclose (child_process)) {
+		if (result == STATE_OK)
+			result = STATE_UNKNOWN;
+		asprintf (&outbuff, "%s (%s)", outbuff, _("snmpget returned an error status"));
+	}
 
 /* 	if (nunits == 1 || i == 1) */
 /* 		printf ("%s %s -%s %s\n", label, state_text (result), outbuff, units); */
@@ -462,31 +473,31 @@ process_arguments (int argc, char **argv)
 		case 'H':									/* Host or server */
 			server_address = optarg;
 			break;
-		case 'p':       /* TCP port number */
+		case 'p':	/* TCP port number */
 			port = optarg;
 			break;
-		case 'm':      /* List of MIBS  */
+		case 'm':	/* List of MIBS  */
 			miblist = optarg;
 			break;
-		case 'n':     /* usesnmpgetnext */
+		case 'n':	/* usesnmpgetnext */
 			usesnmpgetnext = TRUE;
 			break;
-		case 'P':     /* SNMP protocol version */
+		case 'P':	/* SNMP protocol version */
 			proto = optarg;
 			break;
-		case 'L':     /* security level */
+		case 'L':	/* security level */
 			seclevel = optarg;
 			break;
-		case 'U':     /* security username */
+		case 'U':	/* security username */
 			secname = optarg;
 			break;
-		case 'a':     /* auth protocol */
+		case 'a':	/* auth protocol */
 			authproto = optarg;
 			break;
-		case 'A':     /* auth passwd */
+		case 'A':	/* auth passwd */
 			authpasswd = optarg;
 			break;
-		case 'X':     /* priv passwd */
+		case 'X':	/* priv passwd */
 			privpasswd = optarg;
 			break;
 		case 't':	/* timeout period */
@@ -501,9 +512,9 @@ process_arguments (int argc, char **argv)
 			if (strspn (optarg, "0123456789:,") < strlen (optarg))
 				usage2 (_("Invalid critical threshold: %s\n"), optarg);
 			for (ptr = optarg; ptr && jj < MAX_OIDS; jj++) {
-				if (lu_getll (&lower_crit_lim[jj], ptr) == 1)
+				if (llu_getll (&lower_crit_lim[jj], ptr) == 1)
 					eval_method[jj] |= CRIT_LT;
-				if (lu_getul (&upper_crit_lim[jj], ptr) == 1)
+				if (llu_getul (&upper_crit_lim[jj], ptr) == 1)
 					eval_method[jj] |= CRIT_GT;
 				(ptr = index (ptr, ',')) ? ptr++ : ptr;
 			}
@@ -512,9 +523,9 @@ process_arguments (int argc, char **argv)
 			if (strspn (optarg, "0123456789:,") < strlen (optarg))
 				usage2 (_("Invalid warning threshold: %s\n"), optarg);
 			for (ptr = optarg; ptr && ii < MAX_OIDS; ii++) {
-				if (lu_getll (&lower_warn_lim[ii], ptr) == 1)
+				if (llu_getll (&lower_warn_lim[ii], ptr) == 1)
 					eval_method[ii] |= WARN_LT;
-				if (lu_getul (&upper_warn_lim[ii], ptr) == 1)
+				if (llu_getul (&upper_warn_lim[ii], ptr) == 1)
 					eval_method[ii] |= WARN_GT;
 				(ptr = index (ptr, ',')) ? ptr++ : ptr;
 			}
@@ -697,14 +708,14 @@ validate_arguments ()
 	
 	 
 	
-	if (proto == NULL || (strcmp(proto,DEFAULT_PROTOCOL) == 0) ) {        /* default protocol version */
+	if (proto == NULL || (strcmp(proto,DEFAULT_PROTOCOL) == 0) ) {	/* default protocol version */
 		asprintf(&proto, DEFAULT_PROTOCOL);
 		asprintf(&authpriv, "%s%s", "-c ", community);
 	}
-	else if ( strcmp (proto, "2c") == 0 ) {                 /* snmpv2c args */
+	else if ( strcmp (proto, "2c") == 0 ) {		/* snmpv2c args */
 		asprintf(&authpriv, "%s%s", "-c ", community);
 	}
-	else if ( strcmp (proto, "3") == 0 ) {                 /* snmpv3 args */
+	else if ( strcmp (proto, "3") == 0 ) {		/* snmpv3 args */
 		asprintf(&proto, "%s", "3");
 		
 		if ( (strcmp(seclevel, "noAuthNoPriv") == 0) || seclevel == NULL ) {
@@ -819,14 +830,14 @@ check_num (int i)
 
 
 int
-lu_getll (unsigned long *ll, char *str)
+llu_getll (unsigned long long *ll, char *str)
 {
 	char tmp[100];
 	if (strchr (str, ':') == NULL)
 		return 0;
 	if (strchr (str, ',') != NULL && (strchr (str, ',') < strchr (str, ':')))
 		return 0;
-	if (sscanf (str, "%lu%[:]", ll, tmp) == 2)
+	if (sscanf (str, "%llu%[:]", ll, tmp) == 2)
 		return 1;
 	return 0;
 }
@@ -834,14 +845,14 @@ lu_getll (unsigned long *ll, char *str)
 
 
 int
-lu_getul (unsigned long *ul, char *str)
+llu_getul (unsigned long long *ul, char *str)
 {
 	char tmp[100];
-	if (sscanf (str, "%lu%[^,]", ul, tmp) == 1)
+	if (sscanf (str, "%llu%[^,]", ul, tmp) == 1)
 		return 1;
-	if (sscanf (str, ":%lu%[^,]", ul, tmp) == 1)
+	if (sscanf (str, ":%llu%[^,]", ul, tmp) == 1)
 		return 1;
-	if (sscanf (str, "%*u:%lu%[^,]", ul, tmp) == 1)
+	if (sscanf (str, "%*u:%llu%[^,]", ul, tmp) == 1)
 		return 1;
 	return 0;
 }
